@@ -105,13 +105,42 @@ sub get
     my $fresh  = $key =~ s/^\s*fresh\s+//;
     delete $self->{__petal_hash_cache__}->{$key} if ($fresh);
     exists $self->{__petal_hash_cache__}->{$key} and return $self->{__petal_hash_cache__}->{$key};
-    
-    my $res = $self->__FETCH ($key);
+
+    my $res = undef;   
+    if ($Petal::HTML_ERRORS)
+    {
+        $res = eval { $self->__FETCH ($key) };
+        $@ and return "[ Cannot fetch $key. <!-- $@ --> ]";
+    }
+    else
+    {
+        $res = $self->__FETCH ($key);
+    }
+
     $self->{__petal_hash_cache__}->{$key} = $res;
     return $res;
 }
 
 
+sub get_encoded
+{
+    my $self = shift;
+    my $key  = shift;
+    my $res  = $self->get ($key);
+    return unless (defined $res);
+
+    my $no_encode = $key =~ s/^\s*structure\s+//;
+    unless ($no_encode and $no_encode)
+    {
+        $res =~ s/\&/\&amp;/g;
+        $res =~ s/\</\&lt;/g;
+        $res =~ s/\"/\&quot;/g;
+    }
+
+    return $res;
+}
+
+
 sub delete_cached
 {
     my $self  = shift;
@@ -135,14 +164,7 @@ sub __FETCH
     else
     {
 	$key =~ s/^\s*text\s*//;
-	my $res = $self->fetch ($key);
-	if (defined $res and not ref $res)
-	{
-	    $res =~ s/\&/\&amp;/g;
-	    $res =~ s/\</\&lt;/g;
-	    $res =~ s/\"/\&quot;/g;
-	}
-	return $res;
+	return $self->fetch ($key);
     }
 }
 
